@@ -1,11 +1,11 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """
 Construct RestructuredText markup and directives from Python Code.
 """
 
-__version__ = "0.0.3"
+from ._version import __version__
+
 __short_description__ = "Construct RestructuredText markup and directives from Python Code."
 __license__ = "MIT"
 __author__ = "Sanhe Hu"
@@ -16,5 +16,7 @@ __github_username__ = "MacHu-GWU"
 
 try:
     from . import directives, markup
+    from .directives import *
+    from .markup import *
 except:  # pragma: no cover
     pass
