@@ -7,3 +7,5 @@ reStructuredText Directives: http://docutils.sourceforge.net/docs/ref/rst/direct
 from .image import Image
 from .table import ListTable
 from .codeblock import *
+from .toc import TableOfContent
+from .miscellaneous import Include
