@@ -9,3 +9,5 @@ from .header import (
     Header1, Header2, Header3, Header4, Header5, Header6, Header7,
 )
 from .hyperlink import URI, URL, Reference, Ref
+from .bullet_list import BulletList
+from .enum_list import EnumList
